@@ -399,13 +399,15 @@ def set_table_pwd(client, param_object, field, value):
     return param_object
 
 
+
 def display_error(error, args, groups):
     params_text = ''
     sys.stdout.write('\r')
     sys.stdout.flush()
     list_answer = False
+    lesser_errors = ["commonerror", "sysinstalled"]
     varname, comments, values, value, list_value = None, None, None, None, []
-    if error.type != "commonerror":
+    if error.type not in lesser_errors:
         for group in groups:
             for field in group.fields:
                 if field.name == error.field:
@@ -454,7 +456,7 @@ def display_error(error, args, groups):
                     __print(" ")
                     __print.bold.foreground(TextState.Colors.WHITE)("*")
                 __print("\n")
-    elif error.type != "commonerror":
+    elif error.type not in lesser_errors:
         colorPrint.printERROR(params_text % error.message)
     else:
         colorPrint.printWARNING(error.message)
